
Dr.Web pyavdesk documentation
=============================


**Intoduction**

Dr.Web pyavdesk is a Python module, wrapping Dr.Web *dwavdapi* C library to introduce simple yet powerful
interface to manipulatate Dr.Web AV-Desk server resources from within your Python code, making
integration of thirdparty applications with AV-Desk as easy as possible.


Requirements
------------

* Python 2.6+
* Dr.Web *dwavdapi* library
* Python setuptools (to install pyavdesk package using setup.py)


Note on examples
----------------

If you are using Python 3 please take into account that all code examples in this documentation are for Python 2 series syntax.


Contents
--------

.. toctree::
   :maxdepth: 3

   getting_started
   exceptions
   utilities
   server
   administrator
   group
   tariff
   station


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
